/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#if !defined(_VIEW_H)
#define _VIEW_H

#include <stdbool.h>
#include "types.h"

typedef const char *(*get_display_string_cb)(void);
typedef bool (*key_pressed_cb)(key_type key);

void view_set_callbacks(get_display_string_cb get_display_string_func, key_pressed_cb key_pressed_func);
Eina_Bool view_create(void *user_data);
Evas_Object *view_create_win(const char *pkg_name);
Evas_Object *view_create_layout(Evas_Object *parent, const char *edj_file_name, const char *edj_group, const char *part_name);
Evas_Object *view_create_conformant_without_indicator(Evas_Object *win);
Evas_Object *view_create_naviframe(Evas_Object *parent, const char *part_name);
Evas_Object *view_create_background(Evas_Object *parent);
Evas_Object *view_create_table(Evas_Object *parent_widget, Elm_Object_Item *parent_item, const char *part_name);
Evas_Object *view_create_grid(Evas_Object *parent);
Evas_Object *view_create_button(Evas_Object *parent, const char *caption, Evas_Smart_Cb on_click_cb, void *data);
Evas_Object *view_create_label(Evas_Object *parent, const char *caption);
void view_update_display(void);
void view_change_region_format(const char *format);
void view_change_orientation(int orientation);
void view_destroy(void);

#endif
